@@ -1,29 +1,28 @@
 # -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 import io
 import json
 import os
 import socket
 import tempfile
 import time
-from unittest import TestCase
+from unittest import TestCase, mock
+from urllib.error import HTTPError
+from urllib.parse import urlencode
+from urllib.request import urlopen
 
-import mock
 import pytest
 import requests
 
 from mocket import Mocket, mocketize
 from mocket.mockhttp import Entry, Response
-from tests import HTTPError, urlencode, urlopen
 
 recording_directory = tempfile.mkdtemp()
 
 
 class HttpTestCase(TestCase):
     def assertEqualHeaders(self, first, second, msg=None):
-        first = dict((k.lower(), v) for k, v in first.items())
-        second = dict((k.lower(), v) for k, v in second.items())
+        first = {k.lower(): v for k, v in first.items()}
+        second = {k.lower(): v for k, v in second.items()}
         self.assertEqual(first, second, msg)
 
 
@@ -149,7 +148,7 @@ class HttpEntryTestCase(HttpTestCase):
                 "Content-type": "text/plain; charset=utf-8",
             },
         )
-        self.assertEqual(len(Mocket._requests), 1)
+        self.assertEqual(len(Mocket.request_list()), 1)
 
     @mocketize
     def test_sendall_json(self):
@@ -176,7 +175,7 @@ class HttpEntryTestCase(HttpTestCase):
                 "content-type": "application/json",
             },
         )
-        self.assertEqual(len(Mocket._requests), 1)
+        self.assertEqual(len(Mocket.request_list()), 1)
 
     @mocketize
     def test_sendall_double(self):
@@ -188,7 +187,7 @@ class HttpEntryTestCase(HttpTestCase):
         self.assertEqual(response.code, 200)
         response = urlopen("http://testme.org/")
         self.assertEqual(response.code, 200)
-        self.assertEqual(len(Mocket._requests), 3)
+        self.assertEqual(len(Mocket.request_list()), 3)
 
     @mocketize
     def test_mockhttp_entry_collect_duplicates(self):
@@ -201,7 +200,7 @@ class HttpEntryTestCase(HttpTestCase):
             headers={"content-type": "application/json"},
         )
         requests.post("http://testme.org/")
-        self.assertEqual(len(Mocket._requests), 2)
+        self.assertEqual(len(Mocket.request_list()), 2)
         self.assertEqual(Mocket.last_request().path, "/")
 
     @mocketize
@@ -235,7 +234,7 @@ class HttpEntryTestCase(HttpTestCase):
                 "connection": "keep-alive",
             },
         )
-        self.assertEqual(len(Mocket._requests), 1)
+        self.assertEqual(len(Mocket.request_list()), 1)
 
     @mocketize
     def test_file_object(self):
@@ -320,7 +319,7 @@ class HttpEntryTestCase(HttpTestCase):
         Entry.single_register(Entry.POST, url, status=201)
         file_obj = open("tests/fluidicon.png", "rb")
         files = {"content": file_obj}
-        r = requests.post(url, files=files, data={}, verify=False)
+        r = requests.post(url, files=files, data={})
         self.assertEqual(r.status_code, 201)
 
     @mocketize
@@ -336,7 +335,6 @@ class HttpEntryTestCase(HttpTestCase):
         https://github.com/mindflayer/python-mocket/issues/111
         https://gist.github.com/amotl/015ef6b336db55128798d7f1a9a67dea
         """
-
         # Define HTTP conversation.
         url = "http://127.0.0.1:8080/api/data"
         Entry.single_register(Entry.POST, url)
@@ -409,3 +407,21 @@ class HttpEntryTestCase(HttpTestCase):
         response = requests.post(url, json={"test": 22})
         self.assertEqual(response.status_code, 202)
         self.assertEqual(response.json(), {"foo": "bar2"})
+
+    def test_suggestion_for_register_and_body(self):
+        url = "http://foobar.com/path"
+        with self.assertRaises(AttributeError):
+            Entry.register(
+                Entry.POST,
+                url,
+                body='{"foo":"bar0"}',
+            )
+
+    def test_suggestion_for_register_and_status(self):
+        url = "http://foobar.com/path"
+        with self.assertRaises(AttributeError):
+            Entry.register(
+                Entry.POST,
+                url,
+                status=201,
+            )
